@@ -160,7 +160,10 @@ impl ShardedGossipLocal {
                 .as_ref()
                 .map_or(true, |tgt| tgt.cert != peer_cert)
             {
-                inner.metrics.record_remote_round(&remote_agent_list);
+                inner
+                    .metrics
+                    .write()
+                    .record_remote_round(&remote_agent_list);
             }
             // If this is the target then we should clear the when initiated timeout.
             if let Some(tgt) = inner.initiate_tgt.as_mut() {
