@@ -38,7 +38,7 @@ async fn standard_responses(
             Ok(async {
                 Ok(Some((
                     vec![Arc::new(KitsuneOpHash(vec![0; 36]))],
-                    full_time_window(),
+                    full_time_window_inclusive(),
                 )))
             }
             .boxed()
@@ -115,7 +115,7 @@ pub async fn agent_info(agent: Arc<KitsuneAgent>) -> AgentInfoSigned {
     AgentInfoSigned::sign(
         Arc::new(fixt!(KitsuneSpace)),
         agent,
-        u32::MAX / 4,
+        u32::MAX / 2,
         vec![url2::url2!(
             "kitsune-proxy://CIW6PxKxs{}cKwUpaMSmB7kLD8xyyj4mqcw/kitsune-quic/h/localhost/p/5778/-",
             rand_string
