@@ -4,11 +4,12 @@
 /// re-exported dependencies
 pub mod dependencies {
     pub use ::kitsune_p2p_proxy;
+    pub use ::kitsune_p2p_timestamp;
     pub use ::kitsune_p2p_types;
     pub use ::url2;
 }
 
-mod metrics;
+pub mod metrics;
 
 mod types;
 pub use types::*;
